@@ -26,6 +26,7 @@ from polyswarm.client.links import link
 from polyswarm.client.tags import tag
 from polyswarm.client.families import family
 from polyswarm.client.metadata import metadata
+from polyswarm.client.engine import engine
 
 logger = logging.getLogger(__name__)
 
@@ -75,6 +76,8 @@ class ExceptionHandlingGroup(click.Group):
         except (
                 exceptions.NoResultsException,
                 exceptions.NotFoundException,
+                api_exceptions.NoResultsException,
+                api_exceptions.NotFoundException,
         ) as e:
             logger.error(e)
             raise Exit(1)
@@ -139,6 +142,7 @@ commands = [
     scan, wait, lookup, search, live, historical,
     download, cat, stream, rescan, rescan_id,
     rules, link, tag, family, metadata,
+    engine,
 ]
 
 for command in commands:
